@@ -12,7 +12,7 @@ Supports the following request methods:
 
 Format of `host` is the following:
 
-```plain
+``` plain
 http[s]://<hostname>
 ```
 
@@ -20,14 +20,14 @@ http[s]://<hostname>
 
 Example on how to use it in a scenario:
 
-```gherkin
+``` gherkin
 Given a user of type "RestApi" load testing "https://api.example.com"
 Then post request "test/request.j2.json" to endpoint "/api/test"
 Then get request from endpoint "/api/test"
 ```
 
 To change how often the token should be refreshed, default is 3000 seconds:
-```gherkin
+``` gherkin
 And set context variable "auth.refresh_time" to "3500"
 ```
 
@@ -35,7 +35,7 @@ And set context variable "auth.refresh_time" to "3500"
 
 #### Client secret
 
-```gherkin
+``` gherkin
 Given a user of type "RestApi" load testing "https://api.example.com"
 And set context variable "auth.client.tenant" "<tenant name/guid>"
 And set context variable "auth.client.id" to "<client id>"
@@ -47,7 +47,7 @@ And set context variable "auth.client.resource" to "<resource url/guid>"
 
 `auth.user.redirect_uri` needs to correspond to the endpoint that the client secret is registrered for.
 
-```gherkin
+``` gherkin
 Given a user of type "RestApi" load testing "https://api.example.com"
 And set context variable "auth.client.id" to "<client id>"
 And set context variable "auth.user.username" to "alice@example.onmicrosoft.com"
@@ -71,7 +71,7 @@ from locust.env import Environment
 
 import requests
 
-from ..types import GrizzlyResponse, WrappedFunc, GrizzlyResponseContextManager
+from ..types import GrizzlyResponse, RequestType, WrappedFunc, GrizzlyResponseContextManager
 from ..utils import merge_dicts
 from ..types import RequestMethod
 from ..tasks import RequestTask
@@ -570,44 +570,34 @@ class RestApiUser(ResponseHandler, RequestLogger, GrizzlyUser, HttpRequests, Asy
         client = FastHttpSession(
             environment=self.environment,
             base_url=self.host,
-            # should be FastHttpUser, but really, could just be locust.user.users.User ?
-            user=self,  # type: ignore
+            user=self,
             insecure=not self._context.get('verify_certificates', True),
             max_retries=1,
             connection_timeout=60.0,
             network_timeout=60.0,
         )
 
-        return self._request(client, request, {})
+        return self._request(client, request)
 
     def request(self, request: RequestTask) -> GrizzlyResponse:
-        return self._request(
-            self.client, request, {
-                'verify': self._context.get('verify_certificates', True),
-            },
-        )
+        return self._request(self.client, request)
 
     @refresh_token()
-    def _request(self, client: Union[FastHttpSession, ResponseEventSession], request: RequestTask, parameters: Optional[Dict[str, Any]] = None) -> GrizzlyResponse:
+    def _request(self, client: Union[FastHttpSession, ResponseEventSession], request: RequestTask) -> GrizzlyResponse:
         if request.method not in [RequestMethod.GET, RequestMethod.PUT, RequestMethod.POST]:
             raise NotImplementedError(f'{request.method.name} is not implemented for {self.__class__.__name__}')
 
         request_name, endpoint, payload = self.render(request)
 
-        parameters = parameters or {}
-        parameters.update({'headers': self.headers})
+        parameters: Dict[str, Any] = {'headers': self.headers}
 
         url = f'{self.host}{endpoint}'
 
         # only render endpoint once, so needs to be done here
         if isinstance(client, ResponseEventSession):
             parameters.update({
-                'url': url,
                 'request': request,
-            })
-        else:
-            parameters.update({
-                'path': endpoint,
+                'verify': self._context.get('verify_certificates', True),
             })
 
         name = f'{request.scenario.identifier} {request_name}'
@@ -618,7 +608,7 @@ class RestApiUser(ResponseHandler, RequestLogger, GrizzlyUser, HttpRequests, Asy
             except json.decoder.JSONDecodeError as exception:
                 # so that locust treats it as a failure
                 self.environment.events.request.fire(
-                    request_type=request.method.name,
+                    request_type=RequestType.from_method(request.method),
                     name=name,
                     response_time=0,
                     response_length=0,
@@ -633,6 +623,7 @@ class RestApiUser(ResponseHandler, RequestLogger, GrizzlyUser, HttpRequests, Asy
         with client.request(
             method=request.method.name,
             name=name,
+            url=url,
             catch_response=True,
             **parameters,
         ) as response:
